pub struct FileWatcherSubscriber { /* private fields */ }Expand description
Handle used to register watched paths for one logical consumer.
Implementations
Sourceimpl FileWatcherSubscriber
impl FileWatcherSubscriber
Sourcepub fn register_paths(&self, watched_paths: Vec<WatchPath>) -> WatchRegistration
pub fn register_paths(&self, watched_paths: Vec<WatchPath>) -> WatchRegistration
Registers the provided paths for this subscriber and returns an RAII guard that unregisters them on drop.